@@ -425,6 +425,51 @@ class DeletedVersionContent(AnyEntity):
     def is_deletion(self):
         return True
 
+    # data server side internals to be able to create new vcs repo revision
+    # using rql queries
+
+    def _vc_vf(self):
+        """return versioned file associated to a [Deleted]VersionContent entity"""
+        if not hasattr(self, '_vcsrepoinfo'):
+            try:
+                vfeid = self['content_for']
+            except KeyError, ex:
+                raise missing_relation_error(self, 'content_for')
+            vf = self._cw.execute(
+                'Any X, R, FD, FN WHERE X directory FD, X name FN, X eid %(x)s, '
+                'X from_repository R', {'x': vfeid}, 'x').get_entity(0, 0)
+            self._vcsrepo_info = vf
+        return self._vcsrepo_info
+
+    def _vc_prepare(self, vcsrepoeid=None):
+        try:
+            vfeid = self['content_for']
+        except KeyError:
+            raise missing_relation_error(self, 'content_for')
+        session = self._cw
+        if vcsrepoeid is None:
+            # retrieve associated VersionedFile instance
+            vf = session.execute('Any X,D,N,R WHERE X name N, X directory D,'
+                                 'X from_repository R, X eid %(x)s',
+                                 {'x': vfeid}, 'x').get_entity(0, 0)
+            vcsrepoeid = vf.repository.eid
+        try:
+            transaction = session.transaction_data['vctransactions'][vcsrepoeid]
+        except KeyError:
+            raise QueryError('you must create a Revision instance before '
+                             'adding some content')
+        CheckRevisionOp(session, entity=self)
+        return bridge.repository_handler(vcsrepoeid), transaction
+
+
+from cubicweb import QueryError
+from cubes.vcsfile import bridge
+try:
+    from cubes.vcsfile.hooks import missing_relation_error, CheckRevisionOp
+except ImportError:
+    # server part not installed
+    pass
+
 
 class VersionContent(DeletedVersionContent):
     """customized class for VersionContent entities"""
@@ -441,19 +486,6 @@ class VersionContent(DeletedVersionContent):
             'file': self.file.path, 'revision': rev.revision,
             'author': rev.author, 'date': rev.printable_value('creation_date')}
 
-    def posted_data(self, fetch=True):
-        """use this method to get VersionContent.data in
-        [before|after]_add_entity hooks
-        """
-        try:
-            return self.__data
-        except:
-            data = self.pop('data', None)
-            if data is None and fetch:
-                data = self.data
-            self.__data = data
-            return data
-
     def is_deletion(self):
         return False
 
