@@ -28,30 +28,27 @@ def missing_relation_error(entity, rtype):
                                         'eid': entity.eid}}
     return ValidationError(entity.eid, errors)
 
-def _generate_vc_data(gen, linkedvar, rel):
-    linkedvar.accept(gen)
-    return 'VERSION_DATA(%s)' % linkedvar._q_sql
-
 # initialization hooks #########################################################
 
 class ServerStartupHook(Hook):
     """synchronize repository on server startup, and install attribute map
     on the system source sql generator
     """
-    __regid__ = 'serverstartuphook'
-    events = ('server_startup',)
+    __regid__ = 'vcsfile.serverstartuphook'
+    events = ('server_startup', 'server_maintenance')
     def __call__(self):
         repo = self.repo
-        repo.system_source.map_attribute('VersionContent', 'data',
-                                         _generate_vc_data)
-        repo.looping_task(repo.config.get('check-revision-interval', 5*60),
-                          bridge.import_content, repo,
-                          repo.config.get('check-revision-commit-every', 5*60))
+        repo.system_source.set_storage('VersionContent', 'data',
+                                       bridge.VCSStorage())
+        if self.event == 'server_startup':
+            repo.looping_task(repo.config.get('check-revision-interval', 5*60),
+                              bridge.import_content, repo,
+                              repo.config.get('check-revision-commit-every', 1))
 
 
 class AddRepositoryHook(Hook):
     """add repository eid to vcs bridge cache"""
-    __regid__ = 'add_repository_hook'
+    __regid__ = 'vcsfile.add_repository_hook'
     events = ('before_add_entity', )
     __select__ = Hook.__select__ & implements('Repository')
 
@@ -64,41 +61,6 @@ class AddRepositoryHook(Hook):
 
 # internals to be able to create new vcs repo revision using rql queries #######
 
-def _vc_prepare(entity, vcsrepoeid=None):
-    try:
-        vfeid = entity['content_for']
-    except KeyError:
-        raise missing_relation_error(entity, 'content_for')
-    session = entity._cw
-    if vcsrepoeid is None:
-        # retrieve associated VersionedFile instance
-        vf = session.execute('Any X,D,N,R WHERE X name N, X directory D,'
-                             'X from_repository R, X eid %(x)s',
-                             {'x': vfeid}, 'x').get_entity(0, 0)
-        vcsrepoeid = vf.repository.eid
-    try:
-        transaction = session.transaction_data['vctransactions'][vcsrepoeid]
-    except KeyError:
-        raise QueryError('you must create a Revision instance before '
-                         'adding some content')
-    CheckRevisionOp(session, entity=entity)
-    return bridge.repository_handler(vcsrepoeid), transaction
-
-def _vc_vf(entity):
-    """return versioned file associated to a [Deleted]VersionContent entity"""
-    if not hasattr(entity, '_vcsrepoinfo'):
-        try:
-            vfeid = entity['content_for']
-        except KeyError, ex:
-            raise missing_relation_error(entity, 'content_for')
-        session = entity._cw
-        vf = session.execute(
-            'Any X, R, FD, FN WHERE X directory FD, X name FN, X eid %(x)s, '
-            'X from_repository R', {'x': vfeid}, 'x').get_entity(0, 0)
-        entity._vcsrepo_info = vf
-    return entity._vcsrepo_info
-
-
 class VCTransactionOp(Operation):
 
     def precommit_event(self):
@@ -123,7 +85,7 @@ class VCTransactionOp(Operation):
 
 
 class AddRevisionHook(Hook):
-    __regid__ = 'add_revision_hook'
+    __regid__ = 'vcsfile.add_revision_hook'
     events = ('before_add_entity',)
     __select__ = Hook.__select__ & implements('Revision')
 
@@ -160,60 +122,27 @@ class AddRevisionHook(Hook):
 
 
 class AddVersionContentHook(Hook):
-    __regid__ = 'add_version_content_hook'
+    __regid__ = 'vcsfile.add_version_content_hook'
     events = ('before_add_entity',)
     __select__ = Hook.__select__ & implements('VersionContent')
 
     def __call__(self):
         session = self._cw
         entity = self.entity
-        data = self.get_data(entity)
-        # save data for usage in after_add_entity hook below
-        session.transaction_data[(entity.eid, 'data')] = data
         if need_guess(entity.get('data_format'), entity.get('data_encoding')):
-            vf = _vc_vf(entity)
+            vf = entity._vc_vf()
             encoding = bridge.repository_handler(vf.repository.eid).encoding
-            mt, enc = guess_mimetype_and_encoding(data=data, filename=vf.name,
+            mt, enc = guess_mimetype_and_encoding(data=entity.get('data'),
+                                                  filename=vf.name,
                                                   fallbackencoding=encoding)
             if mt and not entity.get('data_format'):
                 entity['data_format'] = unicode(mt)
             if enc and not entity.get('data_encoding'):
                 entity['data_encoding'] = unicode(enc)
-        # skip further processing if the revision is being imported from the
-        # vcs repository
-        if session.is_internal_session:
-            return
-        vf = _vc_vf(entity)
-        vcsrepohdlr, transaction = _vc_prepare(entity, vf.repository.eid)
-        vcsrepohdlr.add_versioned_file_content(session, transaction, vf, entity,
-                                               data)
-
-    def get_data(self, entity):
-        session = entity._cw
-        if session.is_internal_session:
-            vf = _vc_vf(entity)
-            vcsrepohdlr = bridge.repository_handler(vf.repository.eid)
-            return Binary(vcsrepohdlr.file_content(
-                vf.directory, vf.name, vcsrepohdlr.imported_revision))
-        # data not stored in the local database, pop it
-        data = entity.posted_data(fetch=False)
-        if not data:
-            # missing data
-            raise ValidationError(entity, {'data': session.__('required attribute')})
-        return data
-
-
-class AfterAddVersionContentHook(Hook):
-    __regid__ = 'after_add_version_content_hook'
-    events = ('after_add_entity',)
-    __select__ = Hook.__select__ & implements('VersionContent')
-    def __call__(self):
-        # restore data for full text indexation
-        self.entity['data'] = self._cw.transaction_data.pop((self.entity.eid, 'data'))
 
 
 class AddDeletedVersionContentHook(Hook):
-    __regid__ = 'add_deleted_version_content_hook'
+    __regid__ = 'vcsfile.add_deleted_version_content_hook'
     events = ('before_add_entity',)
     __select__ = Hook.__select__ & implements('DeletedVersionContent')
 
@@ -222,14 +151,14 @@ class AddDeletedVersionContentHook(Hook):
         # vcs repository
         if self._cw.is_internal_session:
             return
-        vcsrepohdlr, transaction = _vc_prepare(self.entity)
-        vf = _vc_vf(self.entity)
+        vcsrepohdlr, transaction = self.entity._vc_prepare()
+        vf = self.entity._vc_vf()
         vcsrepohdlr.add_versioned_file_deleted_content(self._cw, transaction, vf,
                                                        self.entity)
 
 
 class AddVersionedFileHook(Hook):
-    __regid__ = 'add_versioned_file_hook'
+    __regid__ = 'vcsfile.add_versioned_file_hook'
     events = ('before_add_entity',)
     __select__ = Hook.__select__ & implements('VersionedFile')
 
@@ -280,7 +209,7 @@ class CheckRevisionOp(Operation):
 
 
 class CheckImmutalbeAttributeHook(Hook):
-    __regid__ = 'check_immutable_attribute_hook'
+    __regid__ = 'vcsfile.check_immutable_attribute_hook'
     events = ('before_update_entity',)
     __select__ = Hook.__select__ & implements('Revision', 'DeletedVersionContent',
                                               'VersionContent')
@@ -295,7 +224,7 @@ class CheckImmutalbeAttributeHook(Hook):
 
 class UpdateRepositoryHook(Hook):
     """add repository eid to vcs bridge cache"""
-    __regid__ = 'update_repository_hook'
+    __regid__ = 'vcsfile.update_repository_hook'
     events = ('before_update_entity', )
     __select__ = Hook.__select__ & implements('Repository')
     def __call__(self):
@@ -320,7 +249,7 @@ class ClassifyVersionedFileHook(Hook):
     """classifies VersionedFile automatically according to their path in the
     repository (require cubicweb-tag and/or cubicweb-folder installed)
     """
-    __regid__ = 'classify_versioned_file_hook'
+    __regid__ = 'vcsfile.classify_versioned_file_hook'
     events = ('after_add_entity', )
     __select__ = Hook.__select__ & implements('VersionedFile')
 
