@@ -18,6 +18,19 @@ from cubicweb import Binary, QueryError
 
 from cubes.vcsfile import repo, bridge
 
+def _read_file_content(root, path):
+    content = StringIO()
+    try:
+        stream = fs.file_contents(root, path)
+    except:
+        return None
+    while 1:
+        data = core.svn_stream_read(stream, core.SVN_STREAM_CHUNK_SIZE)
+        content.write(data)
+        if len(data) < core.SVN_STREAM_CHUNK_SIZE:
+            break
+    core.svn_stream_close(stream)
+    return content.getvalue()
 
 class SVNRepository(repo.VCSRepository):
     type = 'svn'
@@ -81,19 +94,8 @@ class SVNRepository(repo.VCSRepository):
         revision `rev` in the repository
         """
         fsrep = repos.fs(repos.open(self.path))
-        content = StringIO()
         root = fs.revision_root(fsrep, rev)
-        try:
-            stream = fs.file_contents(root, path)
-        except:
-            return None
-        while 1:
-            data = core.svn_stream_read(stream, core.SVN_STREAM_CHUNK_SIZE)
-            content.write(data)
-            if len(data) < core.SVN_STREAM_CHUNK_SIZE:
-                break
-        core.svn_stream_close(stream)
-        return content.getvalue()
+        return _read_file_content(root, path)
 
     def revision_transaction(self, session, entity):
         """open a transaction to create a new revision corresponding to the
@@ -276,11 +278,17 @@ class SVNImporter(delta.Editor):
         #print 'close_directory', baton
         pass
 
+    def _mark_importing(self, path):
+        dir, name = split(path)
+        self.session.transaction_data['vcs_importing'] = (self.repoeid, dir,
+                                                          name, self.rev)
     def add_file(self, path, *args):
         if self .import_revision_content and self.match_path(path):
+            self._mark_importing(path)
             upath = unicode(path, self.encoding, 'replace')
             bridge.import_version_content(
-                self.session, self.repoeid, self.reveid, upath, self.date)
+                self.session, self.repoeid, self.reveid, upath, self.date,
+                data=_read_file_content(self.root, path))
 
     def add_directory(self, path, *args):
         #print 'add_directory', path
@@ -293,9 +301,11 @@ class SVNImporter(delta.Editor):
     def open_file(self, path, *args):
         #print 'open file', path
         if self.match_path(path):
+            self._mark_importing(path)
             upath = unicode(path, self.encoding, 'replace')
             bridge.import_version_content(
-                self.session, self.repoeid, self.reveid, upath, self.date)
+                self.session, self.repoeid, self.reveid, upath, self.date,
+                data=_read_file_content(self.root, path))
 
     def close_file(self, file_baton, text_checksum):
         pass
