@@ -89,9 +89,7 @@ class DeletedVersionContent(EntityType):
 
 class VersionContent(DeletedVersionContent):
     """actual content of a versioned file, for a given revision"""
-    # not required to avoid yams validation error since it's not actually stored
-    # in the database
-    data = Bytes(description=_("file's data"))
+    data = Bytes(description=_("file's data"), required=True)
     data_format = String(required=True, meta=True, maxsize=50,
                          description=_('MIME type of the file.'))
     data_encoding = String(meta=True, maxsize=20,
