@@ -21,7 +21,7 @@ class VCAction(Action):
 
 
 class VCHeadRevisionAction(VCAction):
-    id = 'revhead'
+    __regid__ = 'revhead'
     __select__ = VCAction.__select__ & rql_condition(
         'X from_revision XR, XR revision V, NV from_revision NVR, '
         'NVR revision > V, X content_for VCF, NV content_for VCF')
@@ -38,7 +38,7 @@ class VCHeadRevisionAction(VCAction):
 
 
 class VCAllRevisionsAction(VCAction):
-    id = 'revall'
+    __regid__ = 'revall'
 
     title = _('all revisions')
     order = 110
@@ -51,7 +51,7 @@ class VCAllRevisionsAction(VCAction):
 
 
 class VCRevisionModifiedFilesAction(VCAction):
-    id = 'revfiles'
+    __regid__ = 'revfiles'
 
     title = _('files modified at this revision')
     order = 120
@@ -68,7 +68,7 @@ class VCRevisionModifiedFilesAction(VCAction):
 
 
 class VCRevisionAllFilesAction(VCAction):
-    id = 'revallfiles'
+    __regid__ = 'revallfiles'
 
     title = _('repository content at this revision')
     order = 121
@@ -88,7 +88,7 @@ class VFAction(Action):
 
 
 class VFAllRevisionsAction(VFAction):
-    id = 'revall'
+    __regid__ = 'revall'
 
     title = _('all revisions')
     order = 110
@@ -99,7 +99,7 @@ class VFAllRevisionsAction(VFAction):
                               'X eid %s' % self.rset[0][0])
 
 class VFHEADRevisionAction(VFAction):
-    id = 'revhead'
+    __regid__ = 'revhead'
 
     title = _('HEAD')
     order = 109
@@ -112,14 +112,14 @@ class VFHEADRevisionAction(VFAction):
 
 
 # deactivate copy action for entities coming from the svn source
-CopyAction.__select__ = CopyAction.__select__ & but_etype(
+CopyAction.__select__ = CopyAction.__select__ & ~implements(
     'Revision', 'VersionedFile', 'VersionContent', 'DeletedVersionContent')
 
 
 # you should usually choose between one of the two ways below to submit new
 # revisions of versioned files
 class VFAddRevisionAction(VFAction):
-    id = 'addrevision'
+    __regid__ = 'addrevision'
 
     title = _('actions_addrevision')
     order = 111
@@ -134,7 +134,7 @@ class VFAddRevisionAction(VFAction):
 
 
 class VFPutUpdateAction(VFAction):
-    id = 'vfnewrevaction'
+    __regid__ ='vfnewrevaction'
 
     title = _('upload revision')
 
@@ -143,7 +143,7 @@ class VFPutUpdateAction(VFAction):
 
 
 class VFRmAction(VFAction):
-    id = 'vcsrmaction'
+    __regid__ = 'vcsrmaction'
     __select__ = VFAction.__select__ & \
                  score_entity(lambda x: not x.deleted_in_branch())
 
